@@ -323,7 +323,16 @@ def getVideoFromXorgLog(prefix="/", available_drivers=()):
                         filter(lambda x: "drv" in x and reDriver.search(x),
                                readLinesFile(xorg_log_file)))))
                 if matchStrs:
-                    return matchStrs[-1]
+                    reUnload = re.compile('|'.join('UnloadModule: "(%s)"' % x
+                        for x in matchStrs))
+                    matchUnload = [x.group(1) for x in 
+                        (reUnload.search(x) for x in 
+                        readLinesFile(xorg_log_file)) if x]
+                    for drv in matchUnload:
+                        if drv in matchStrs:
+                            matchStrs.remove(drv)
+                    if matchStrs:
+                        return matchStrs[-1]
     return ""
 
 
