@@ -56,8 +56,9 @@ reVerSplit = re.compile(r"^(?:.*/%s/)?(?:(\w+-\w+)/)?(.*?)-(([^-]+?)"
 
 class RepositoryPath(object):
     Layman = '/var/lib/layman'
-    Calculate = path.join(Layman, "calculate")
-    Distros = path.join(Layman, "distros")
+    Repos = "/var/db/pkg"
+    Calculate = path.join(Repos, "calculate")
+    Distros = path.join(Repos, "distros")
     Gentoo = '/usr/portage'
     CalculateProfiles = path.join(Calculate, "profiles")
     CalculateTemplates = path.join(CalculateProfiles, "templates")
@@ -274,6 +275,79 @@ def searchProfile(dirpath, configname, repository_sub=None):
     return list(search(dirpath))
 
 
+class ReposConf(object):
+    def __init__(self, conffile, confdir, prefix="/"):
+        self.conffile = conffile
+        self.prefix = prefix
+        self.confdir = confdir
+
+    def add_default(self, config):
+        if config["DEFAULT"].get("main-repo") is None:
+            config["DEFAULT"]["main-repo"] = "gentoo"
+
+    def add(self, rname, rurl, rpath):
+        if not self.conffile:
+            return
+        conffile = pathJoin(self.prefix, self.conffile)
+        config = ConfigParser(strict=False)
+        config.read(conffile, encoding="utf-8")
+        if not config.has_section(rname):
+            config.add_section(rname)
+        for k, v in {'auto-sync': 'Yes',
+                     'priority': '50',
+                     'sync-uri': rurl,
+                     'sync-type': 'calculate',
+                     'location': rpath}.items():
+            config.set(rname, k, v)
+        self.add_default(config)
+        with open(conffile, 'wb') as f:
+            config.write(f)
+
+    def remove(self, rname):
+        if not self.conffile:
+            return
+        conffile = pathJoin(self.prefix, self.conffile)
+        config = ConfigParser(strict=False)
+        config.read(conffile, encoding="utf-8")
+        if config.has_section(rname):
+            config.remove_section(rname)
+            self.add_default(config)
+            with open(conffile, 'wb') as f:
+                config.write(f)
+
+    def get_calculate_repositories(self):
+        """
+        Возвращает Calculate, не Portage репозитории (название, путь)
+        """
+        conffile = pathJoin(self.prefix, self.conffile)
+        config = ConfigParser(strict=False)
+        config.read(conffile, encoding="utf-8")
+        for rep in config.sections():
+            if rep != "gentoo":
+                location = config[rep]["location"]
+                if location:
+                    yield rep, location
+
+    def get_other_repositories(self):
+        """
+        Возвращает не-Calculate, не Portage репозитории (название, путь)
+        """
+        confdir = pathJoin(self.prefix, self.confdir)
+        conffn = pathJoin(self.prefix, self.conffile)
+        skip_reps = {x[0] for x in self.get_calculate_repositories()}
+        skip_reps.add("gentoo")
+        for conffile in glob.glob("%s/*" % confdir):
+            if conffile == conffn:
+                continue
+            config = ConfigParser(strict=False)
+            config.read(conffile, encoding="utf-8")
+            for rep in config.sections():
+                if rep not in skip_reps:
+                    location = config[rep]["location"]
+                    if location:
+                        yield rep, location
+
+
 class Layman(object):
     """
     Объект для управления репозиториями Layman
